# Automation Library

## Descripción
La biblioteca `azucar_web_driver` facilita la automatización de navegadores web usando Selenium. Ideal para tareas de navegación y pruebas automatizadas.

## Instalación
Instala desde GitHub:

pip install git+https://github.com/juank704/azucar_web_driver.git

## Uso
```python
from automation.chrome_factory import ChromeFactory
driver = ChromeFactory.create_instance()
```

## Contribuciones
Contribuciones son bienvenidas. Envía tus PRs al repositorio.

## Licencia
Licenciado bajo [MIT]

## Contacto
Para soporte: [juan_k704@hotmail.com]
